from cpl.application import StartupABC
from cpl.configuration import ConfigurationABC, ConsoleArgument
from cpl.dependency_injection import ServiceProviderABC, ServiceCollectionABC

from lexer.abc.lexer_abc import LexerABC
from lexer.service.lexer_service import LexerService
from runtime.abc.runtime_service_abc import RuntimeServiceABC
from runtime.service.runtime_service import RuntimeService


class Startup(StartupABC):

    def __init__(self, config: ConfigurationABC, services: ServiceCollectionABC):
        StartupABC.__init__(self)

        self._configuration = config
        self._environment = self._configuration.environment
        self._services = services

    def configure_configuration(self) -> ConfigurationABC:
        self._configuration.add_console_argument(ConsoleArgument('-', 'p', [], ' ', is_value_token_optional=True))
        self._configuration.add_console_arguments()

        return self._configuration

    def configure_services(self) -> ServiceProviderABC:
        self._services.add_singleton(LexerABC, LexerService)
        self._services.add_singleton(RuntimeServiceABC, RuntimeService)

        return self._services.build_service_provider()
